@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '2.51';
+our $VERSION = '2.65';
 
 use DateTime::TimeZone;
 use DateTime::TimeZone::OlsonDB;
@@ -73,8 +73,8 @@ sub expand_observances {
             type                 => 'observance',
             utc_start_datetime   => $obs->utc_start_datetime,
             local_start_datetime => $obs->local_start_datetime,
-            short_name           => $obs->formatted_short_name($letter),
-            observance           => $obs,
+            short_name => $obs->formatted_short_name( $letter, $rule ),
+            observance => $obs,
             $rule ? ( rule => $rule ) : (),
         );
 
@@ -133,18 +133,14 @@ sub add_change {
 
         if (   $last_change->short_name eq $change->short_name
             && $last_change->total_offset == $change->total_offset
-            && $last_change->is_dst == $change->is_dst
-            && $last_change->observance eq $change->observance ) {
+            && $last_change->is_dst == $change->is_dst ) {
             my $last_rule = $last_change->rule || q{};
             my $new_rule  = $change->rule      || q{};
 
-            if ( $last_rule eq $new_rule ) {
-                ## no critic (InputOutput::RequireCheckedSyscalls)
-                print "Skipping identical change\n"
-                    if $DateTime::TimeZone::OlsonDB::DEBUG;
-
-                return;
-            }
+            ## no critic (InputOutput::RequireCheckedSyscalls)
+            print "Skipping identical change\n"
+                if $DateTime::TimeZone::OlsonDB::DEBUG;
+            return;
         }
 
         push @{ $self->{changes} }, $change;
